@@ -1,10 +1,11 @@
-__version__="2.5.3"
+__version__="2.7.0"
 
 # import client
 from aoa.api_client import AoaClient
 
 # import APIs into api package
 from aoa.api.dataset_api import DatasetApi
+from aoa.api.dataset_template_api import DatasetTemplateApi
 from aoa.api.model_api import ModelApi
 from aoa.api.project_api import ProjectApi
 from aoa.api.trainer_api import TrainerApi
@@ -12,6 +13,8 @@ from aoa.api.trained_model_api import TrainedModelApi
 from aoa.api.trained_model_event_api import TrainedModelEventApi
 from aoa.api.job_api import JobApi
 from aoa.api.job_event_api import JobEventApi
+from aoa.api.deployment_api import DeploymentApi
+from aoa.api.api_iterator import ApiIterator
 
 # import repo into api package
 from aoa.model_utility.model_utility import ModelUtility
