@@ -1,10 +1,13 @@
 from __future__ import absolute_import
-from typing import Dict
+from typing import Dict, List
 
-from aoa.api.base_api import BaseApi
+from aoa.api.iterator_base_api import IteratorBaseApi
+
+import requests
+import os
 
 
-class TrainedModelApi(BaseApi):
+class TrainedModelApi(IteratorBaseApi):
 
     path = "/api/trainedModels/"
 
@@ -280,3 +283,79 @@ class TrainedModelApi(BaseApi):
             header_params,
             query_params,
             transition_request)
+
+    def save(self, trained_model: Dict[str, str], artefacts: List[str]):
+        """
+        register an external TrainedModel and upload the associated artefacts
+
+        Parameters:
+           trained_model (dict): External TrainedModel to register
+           artefacts (list): The list of artefacts to upload for this model version
+
+        Returns:
+            (dict): TrainedModel
+        """
+        header_vars = ['AOA-Project-ID', 'Accept']
+        header_vals = [
+            self.aoa_client.project_id,
+            self.aoa_client.select_header_accept([
+                'application/json',
+                'application/hal+json',
+                'text/uri-list',
+                'application/x-spring-data-compact+json'])]
+        header_params = self.generate_params(header_vars, header_vals)
+
+        self.required_params(['modelId'], trained_model)
+
+        query_params = {}
+
+        response = self.aoa_client.post_request(
+            self.path,
+            header_params,
+            query_params,
+            trained_model)
+
+        self.upload_artefacts(artefacts, response['id'])
+
+        return response
+
+    def upload_artefacts(self, artefacts, trained_model_id):
+        for artefact in artefacts:
+            query_params = {
+                'objectKey': "{}".format(os.path.basename(artefact))
+            }
+            header_params = {
+                'AOA-Project-ID': "{}".format(self.aoa_client.project_id)
+            }
+            signed_url = self.aoa_client.get_request("/api/trainedModels/{}/artefacts/signedUploadUrl".format(trained_model_id), header_params, query_params)
+
+            upload_resp = requests.put(signed_url['endpoint'], data=open(artefact, 'rb'))
+            upload_resp.raise_for_status()
+
+    def approve(self, trained_model_id: str, note: str):
+        transition_request = dict()
+        transition_request['status'] = 'APPROVED'
+        transition_request['metadata'] = {'note': note}
+
+        return self.transition(trained_model_id, transition_request)
+
+    def reject(self, trained_model_id: str, note: str):
+        transition_request = dict()
+        transition_request['status'] = 'REJECTED'
+        transition_request['metadata'] = {'note': note}
+
+        return self.transition(trained_model_id, transition_request)
+
+    def deploy(self, trained_model_id: str, engine_type: str):
+        transition_request = dict()
+        transition_request['status'] = 'DEPLOYED'
+        transition_request['metadata'] = {'type': engine_type}
+
+        return self.transition(trained_model_id, transition_request)
+
+    def retire(self, trained_model_id: str, deployment_id: str):
+        transition_request = dict()
+        transition_request['status'] = 'RETIRED'
+        transition_request['metadata'] = {'deploymentId': deployment_id}
+
+        return self.transition(trained_model_id, transition_request)
