@@ -16,6 +16,7 @@ class AoaClient(object):
         self.project_id = None
         self.auth = None, None
         self.aoa_url = None
+        self.s3_bucket = None
 
         self.__parse_aoa_config(**kwargs)
 
@@ -27,12 +28,22 @@ class AoaClient(object):
     def __parse_kwargs(self, **kwargs):
         self.aoa_url = kwargs.get("aoa_url", self.aoa_url)
 
-        if "aoa_credentials" in kwargs:
-            self.auth = AoaAuth(kwargs["aoa_credentials"])
+        if "auth_mode" in kwargs:
+            auth_mode = kwargs["auth_mode"]
+            if auth_mode == "basic":
+                if "aoa_credentials" in kwargs:
+                    self.auth = AoaAuth(kwargs["aoa_credentials"])
 
-        if "auth_user" in kwargs and "auth_pass" in kwargs:
-            credentials = b64encode("{}:{}".format(kwargs["auth_user"], kwargs["auth_pass"]).encode()).decode()
-            self.auth = AoaAuth(credentials)
+                if "auth_user" in kwargs and "auth_pass" in kwargs:
+                    credentials = b64encode("{}:{}".format(kwargs["auth_user"], kwargs["auth_pass"]).encode()).decode()
+                    self.auth = AoaAuth(credentials)
+
+            elif auth_mode == "kerberos":
+                from requests_kerberos import HTTPKerberosAuth, OPTIONAL
+                self.auth=HTTPKerberosAuth(mutual_authentication=OPTIONAL)
+
+            else:
+                raise Exception("Auth mode: {} not supported.".format(auth_mode))
 
         if "verify_connection" in kwargs:
             self.verify_aoa_connection = kwargs["verify_connection"]
@@ -40,9 +51,20 @@ class AoaClient(object):
     def __parse_env_variables(self):
         self.aoa_url = os.environ.get("AOA_URL", self.aoa_url)
 
-        if "AOA_API_AUTH_USER" in os.environ and "AOA_API_AUTH_PASS" in os.environ:
-            credentials = b64encode("{}:{}".format(os.environ["AOA_API_AUTH_USER"], os.environ["AOA_API_AUTH_PASS"]).encode()).decode()
-            self.auth = AoaAuth(credentials)
+        auth_mode = os.environ.get("AOA_API_AUTH_MODE")
+
+        if auth_mode == "basic":
+            if "AOA_API_AUTH_USER" in os.environ and "AOA_API_AUTH_PASS" in os.environ:
+                credentials = b64encode("{}:{}".format(os.environ["AOA_API_AUTH_USER"],
+                                                       os.environ["AOA_API_AUTH_PASS"]).encode()).decode()
+                self.auth = AoaAuth(credentials)
+
+            elif auth_mode == "kerberos":
+                from requests_kerberos import HTTPKerberosAuth, OPTIONAL
+                self.auth=HTTPKerberosAuth(mutual_authentication=OPTIONAL)
+
+            else:
+                raise Exception("Auth mode: {} not supported.".format(auth_mode))
 
     def set_project_id(self, project_id: str):
         """
