@@ -67,7 +67,8 @@ class ModelUtility(object):
     def __add_framework_specific_attributes(self):
         if self.model_template == "pyspark":
             self.model["automation"] = {
-                "trainingEngine": "pyspark"
+                "trainingEngine": "pyspark",
+                "scoringEngine": "pyspark"
             }
 
     def __create_model_structure(self, model_path):
@@ -131,6 +132,10 @@ class ModelUtility(object):
         with open(config_file, 'w+') as f:
             yaml.dump(config, f, default_flow_style=False)
 
+    def repo_config_exists(self, repo_path=None):
+        path = repo_path if repo_path else self.base_path
+        return Path(os.path.join(path, ".aoa")).is_file()
+
 
 
 
