@@ -28,14 +28,22 @@ class TrainModel(BaseModel):
                 BaseModel.get_model_id(model_path)
 
         model_artefacts_path = ".artefacts/{}/".format(model_id)
+        model_artefacts_output_path = ".artefacts/{}/output/".format(model_id)
         if os.path.exists(model_artefacts_path):
             self.logger.debug("Cleaning local model artefact path: {}".format(model_artefacts_path))
             shutil.rmtree(model_artefacts_path)
 
-        os.makedirs(model_artefacts_path)
+        os.makedirs(model_artefacts_output_path)
 
         try:
-            os.symlink(model_artefacts_path, "./models", target_is_directory=True)
+            if os.path.exists("./artifacts"):
+                os.remove("./artifacts")
+
+            if os.path.exists("./models"):
+                os.remove("./models")
+
+            os.symlink(model_artefacts_path, "./artifacts", target_is_directory=True)
+            os.symlink(model_artefacts_output_path, "./models", target_is_directory=True)
 
             model_dir = model_path + model_id
 
@@ -56,7 +64,7 @@ class TrainModel(BaseModel):
             engine = self._BaseModel__get_engine(model_definition)
             if engine == "python" or engine == "pyspark":
                 if engine == "pyspark":
-                    self._BaseModel__configure_pyspark(model_definition, model_artefacts_path)
+                    self._BaseModel__configure_pyspark(model_definition, model_artefacts_path, model_dir)
 
                 sys.path.append(model_dir)
                 import model_modules
@@ -66,20 +74,22 @@ class TrainModel(BaseModel):
                 self.__train_sql(model_dir, data_conf, model_conf, **cli_model_kargs)
 
             elif engine == "R":
-                cmd = self.model_utility.dir_path + "/run_model.R {} {} {} {}".format(model_id, "train", dataset_path, base_path)
-                subprocess.check_call(cmd, shell=True)
+                self._BaseModel__run_r_model(model_id, base_path, data_conf, "train")
 
             else:
                 raise Exception("Unsupported engine: {}".format(engine))
 
-            self.logger.info("Artefacts can be found in: {}".format(model_artefacts_path))
+            self.logger.info("Artefacts can be found in: {}".format(model_artefacts_output_path))
             self.__cleanup()
         except:
             self.__cleanup()
             raise
 
     def __cleanup(self):
-        os.remove("./models")
+        if os.path.exists("./artifacts"):
+            os.remove("./artifacts")
+        if os.path.exists("./models"):
+            os.remove("./models")
 
     def __train_sql(self, model_dir, data_conf, model_conf, **kwargs):
         from teradataml.context.context import get_connection
